# -*- coding: utf-8 -*-

import os

__tests__ = os.path.dirname(os.path.realpath(__file__))
__base__ = os.path.realpath(os.path.join(__tests__, '..'))
__resources__ = os.path.join(__tests__, 'resources')
